@@ -203,8 +203,11 @@ class ExternalServices(Cacher):
                 for namespace in filter(lambda ns: ns.metadata.name not in EXCUDED_NAMESPACES, namespaces.items):
                     for service in v1.list_namespaced_service(namespace.metadata.name).items:
                         svc_md = service.metadata
-                        svc_local_addr = f'{svc_md.name}.{svc_md.namespace}:{str(service.spec.ports[0].target_port)}'
-                        _connect_n_explore(svc_local_addr, svc_md.name, svc_md.namespace)
+                        if svc_md is not None and service.spec is not None \
+                           and service.spec.ports and service.spec.ports[0] is not None:
+                            svc_local_addr = \
+                                f'{svc_md.name}.{svc_md.namespace}:{str(service.spec.ports[0].target_port)}'
+                            _connect_n_explore(svc_local_addr, svc_md.name, svc_md.namespace)
         elif cfg_explore_localhost:
             for local_port in range(8080, 8089):  # Explore local ports 8080..8088
                 if ('localhost', str(local_port)) not in fpatterns_by_addr:
